.. |pypi_download| image:: https://img.shields.io/pypi/dm/trame-leaflet

trame-leaflet |pypi_download|
===========================================================================

trame-leaflet extends trame **widgets** with components from vue-leaflet.

This package is under the same MIT License as `Vue-Leaflet <https://github.com/vue-leaflet/Vue2Leaflet/blob/master/LICENSE>`_ which that library embeds.

Leaflet integration in trame allows you to create map views with useful widgets.


How to use it?
```````````````````````````````````````````````````````````

Using the Python library

.. code-block:: python

    from trame.widgets import leaflet


JavaScript dependency
-----------------------------------------------------------

This Python package bundle the ``leaflet@1.8.0`` and ``vue2-leaflet@2.7.1`` JavaScript libraries. 
For vue3 we also bundle ``@vue-leaflet/vue-leaflet@0.10.1`` JavaScript librarie.
If you would like us to upgrade it, `please reach out <https://www.kitware.com/trame/>`_.